@@ -24,13 +24,14 @@ use bls::PublicKey as BlsPublicKey;
 use dashmap::{self, mapref::multiple::RefMulti, DashMap};
 use secured_linked_list::SecuredLinkedList;
 use std::iter::{self, Iterator};
+use std::sync::Arc;
 use xor_name::{Prefix, XorName};
 
 /// Container for storing information about other sections in the network.
 #[derive(Debug, Clone)]
 pub(crate) struct NetworkPrefixMap {
     /// Map of sections prefixes to their latest signed section authority providers.
-    sections: DashMap<Prefix, SectionAuth<SectionAuthorityProvider>>,
+    sections: Arc<DashMap<Prefix, SectionAuth<SectionAuthorityProvider>>>,
     /// The network's genesis public key
     genesis_pk: BlsPublicKey,
 }
@@ -39,7 +40,7 @@ impl NetworkPrefixMap {
     /// Create an empty container
     pub(crate) fn new(genesis_pk: BlsPublicKey) -> Self {
         Self {
-            sections: DashMap::new(),
+            sections: Arc::new(DashMap::new()),
             genesis_pk,
         }
     }
@@ -114,6 +115,7 @@ impl NetworkPrefixMap {
         signed_section_auth: SectionAuth<SectionAuthorityProvider>,
         proof_chain: &SecuredLinkedList,
     ) -> Result<bool> {
+        trace!("Attempting to update prefixmap");
         let section_key = match self.section_by_prefix(&signed_section_auth.value.prefix()) {
             Ok(sap) => sap.section_key(),
             Err(_) => self.genesis_pk,
